@@ -1,7 +1,7 @@
 import re
 
 from pymafia import ash
-from pymafia.property_ import get_property
+from pymafia.preference import get_property
 
 
 def have() -> bool:
